const mysql = require('mysql2/promise');
const config = require('./config');

const pool = mysql.createPool(config.dbConfig);

module.exports = {
    async query(sql, params) {
        try {
            const [results] = await pool.execute(sql, params);
            return results;
        } catch (error) {
            console.error('Database Error:', error);
            throw error;
        }
    },
    
    async addUser(userId, username) {
        const sql = 'INSERT IGNORE INTO users (user_id, username) VALUES (?, ?)';
        return this.query(sql, [userId, username]);
    },
    
    async isAdmin(userId) {
        const sql = 'SELECT * FROM admins WHERE user_id = ?';
        const result = await this.query(sql, [userId]);
        return result.length > 0;
    }
};
