const { Telegraf } = require('telegraf');
const config = require('./config');
const userCommands = require('./commands/user');
const adminCommands = require('./commands/admin');
const callbackHandler = require('./handlers/callback');
const messageHandler = require('./handlers/message');

const bot = new Telegraf(config.botToken);

// تسجيل الأوامر
bot.command('start', userCommands.start);
bot.command('help', userCommands.help);
bot.command('ban', adminCommands.ban);
bot.command('unban', adminCommands.unban);

// معالجة الأزرار
bot.on('callback_query', callbackHandler.handleCallback);

// معالجة الرسائل
bot.on('message', messageHandler.handleMessage);

// معالجة الأخطاء
bot.catch((err, ctx) => {
    console.error(`Error for ${ctx.updateType}:`, err);
    ctx.reply('عذراً، حدث خطأ ما').catch(console.error);
});

// تشغيل البوت
bot.launch()
    .then(() => console.log('Bot is running...'))
    .catch(console.error);

// التعامل مع إيقاف البوت بشكل آمن
process.once('SIGINT', () => bot.stop('SIGINT'));
process.once('SIGTERM', () => bot.stop('SIGTERM'));
